API
====

autopew
--------

.. toctree::
  :glob:
  :maxdepth: 1

  api/pew


autopew\.transform
------------------------

.. automodule:: autopew.transform
  :noindex:

.. toctree::
  :glob:
  :maxdepth: 1

  api/transform/transform
  api/transform/affine
  api/transform/vis


autopew\.io
------------------------

.. automodule:: autopew.io
  :noindex:

.. toctree::
  :glob:
  :maxdepth: 1

  api/io/io
  api/io/laser/chromium
  api/io/EPMA/JEOL


autopew\.gui
------------------------

.. toctree::
  :maxdepth: 1

  api/gui


autopew\.image
------------------------

.. automodule:: autopew.image
  :noindex:

.. toctree::
  :glob:
  :maxdepth: 1

  api/image


autopew\.graph
------------------------

.. automodule:: autopew.graph

.. toctree::
  :maxdepth: 2

  api/graph


autopew\.util
------------------------

.. automodule:: autopew.util
  :noindex:

.. toctree::
  :maxdepth: 1

  api/util/plot
  api/util/meta
